@@ -27,10 +27,11 @@ def get_worker_profile(ip_addr):
 def error_handler(worker_ip, return_obj):
 	if (return_obj['errcode'] == 1):
 		# an error occured in worker, raise it
-		(error_class, error_instance) = return_obj['result']
+		(error_info, error) = return_obj['result']
 
-		print('an error occured in worker at '+str(worker_ip)+':')
-		raise(error_instance)
+		print('the following error occured in worker at '+str(worker_ip)+':')
+		print(error_info)
+		raise(error)
 
 	else:
 		# returns the result
@@ -46,24 +47,10 @@ def get_simplex_rpc_stub(worker_ip, rpc_name):
 		
 		# makes the calling request
 		status, text = await async_POST(url=url , data={'msg': serialize((args, kwargs))})
-		# deserializes return object from worker
-		return_obj = deserialize(text)
-		return error_handler(worker_ip, return_obj)
 
-	return simplex_rpc_stub
+		if (text =='duplex'):
+			raise(BaseException('simplex call sent to duplex RPC'))
 
-def get_multicast_simplex_rpc_stub(worker_ips, rpc_name):
-
-	# URLs of RPCs
-	get_url = lambda ip : 'http://'+str(ip)+':'+str(comms_config.worker_port)+'/'+default_rpc_config['endpoint_prefix']+rpc_name
-	urls = [get_url(ip) for ip in worker_ips]
-
-	# this function makes a calling request to a simplex RPC on the worker with IP worker_ip to the RPC named rpc_name
-	async def multicast_simplex_rpc_stub(arg_list, kwargs_list, shared_args, shared_kwargs):
-		
-		# makes the calling requests
-
-		status, text = await async_POST(url=url , data={'msg': serialize((args, kwargs))})
 		# deserializes return object from worker
 		return_obj = deserialize(text)
 		return error_handler(worker_ip, return_obj)
@@ -95,7 +82,7 @@ def get_duplex_rpc_stub(worker_ip, rpc_name):
 		return_obj = deserialize(text)
 
 		# raises exception if the receiving RPC is simplex, not duplex
-		if (return_obj == 'simplex'):
+		if (return_obj != 'duplex'):
 			print(return_obj)
 			raise(BaseException('duplex call sent to simplex RPC'))
 
