@@ -1,14 +1,17 @@
 from .config import comms_config
 from .utils import deserialize, serialize, POST
+from .inline_executor import InlineExecutor, inline_lock
 
 from flask import Flask
 from flask import request as route_req
 from multiprocessing import Process, Manager
+from threading import Thread
 import threading
 import requests
 import inspect
 import sys
 import asyncio
+import traceback
 
 # catches any errors in fn, and handles them properly
 def error_wrapper(fn):
@@ -24,13 +27,9 @@ def error_wrapper(fn):
 			return_object['result'] = fn(*args, **kwargs)
 
 		except:
-			# catch and return all errors
-			error_info = sys.exc_info()
-			error_class = error_info[0]
-			error_instance = error_info[1]
 
 			return_object['errcode'] = 1
-			return_object['result'] = (error_class, error_instance)
+			return_object['result'] = (traceback.format_exc(), sys.exc_info()[1])
 
 		return return_object
 
@@ -47,18 +46,6 @@ def async_wrapper(fn):
 # adds code to deserialize parameters from the request and return its results through the response
 def simplex_wrapper(fn, executor):
 
-	# this function simply runs fn as normal, not in a thread or process
-	def run_inline():
-		# calculates the parameters of the function
-		params_str = route_req.form['msg']
-		args, kwargs = deserialize(params_str)
-
-		# runs the function
-		return_object = error_wrapper(fn)(args, kwargs)
-
-		# serilizes and returns the function's result
-		return serialize(return_object)
-
 	def wrapped_fn():
 
 		mp_manager = Manager()
@@ -91,12 +78,10 @@ def simplex_wrapper(fn, executor):
 
 		return result_holder['result']
 
-	if (executor.__name__ == 'Thread'):
-		# flask runs routes in threads by default, so if the executor is a thread we can just run it inline
-		wrapped_fn = run_inline
-
 	return wrapped_fn
 
+
+
 # wraps fn in the needed for duplex communication pattern
 # adds code to deserialize parameters from the request and return its results through the a separate request
 def duplex_wrapper(fn, executor):
@@ -127,10 +112,25 @@ def duplex_wrapper(fn, executor):
 			data = {'msg': serialize((call_id, return_object))}
 			requests.post(url=url, data=data)
 
+
 		params_str = route_req.form['msg']
 		calling_ip = route_req.remote_addr
 
-		fn_executor = executor(target=wrk_fn, args=(fn, params_str, calling_ip))
+		# because flask, and WSGI servers in general, cannot schedule code to execute after a route completes, inline duplex RPCs would have to send the returning request before the calling request completes
+		# to prevent this, we must run the RPC in a separate thread, and to preserve synchronous bahavior, we must use a threadlock with other inline RPCs. This will ensure no two inline RPCs are executing at the same time.
+		fn_executor = None
+		if(executor == InlineExecutor):
+
+			def inline_lock_fn(fn, params_str, calling_ip):
+				with inline_lock:
+					result = wrk_fn(fn, params_str, calling_ip)
+
+				return result
+
+			fn_executor = Thread(target=inline_lock_fn, args=(fn, params_str, calling_ip))
+		else:
+			fn_executor = executor(target=wrk_fn, args=(fn, params_str, calling_ip))
+
 		fn_executor.deamon = True
 		fn_executor.start()
 
