@@ -3,9 +3,7 @@ from types import SimpleNamespace
 default_rpc_config = {
 	'comms_pattern': 'simplex',
 	'endpoint_prefix': 'rpc/',
-	'executor': 'Thread',
-	'log_errors': False,
-	'new_process': False
+	'executor': 'inline'
 }
 
 comms_config = {
