@@ -4,12 +4,14 @@
 from .utils import deserialize, serialize, get_self_ip
 from .comms_wrappers import simplex_wrapper, duplex_wrapper
 from .config import comms_config, default_rpc_config
+from .inline_executor import InlineExecutor
 
 from flask import Flask
 from flask import request as route_req
 from multiprocessing import Process
 import threading
 import inspect
+import copy
 
 # where the rpcs being offered are stored
 rpcs = []
@@ -17,8 +19,8 @@ rpcs = []
 ip_addr = get_self_ip()
 # the app that listens for incomming http requests
 app = Flask(__name__)
-# app.logger.disabled = True
 name = 'worker'
+node_type = 'worker'
 
 # a default route to serve up what rpcs this worker offers, and their configuration
 @app.route('/_get_profile', methods=['GET'])
@@ -47,11 +49,13 @@ def kill():
 # a default route to provide basic info about the axon node, namely, that it's a worker
 @app.route('/_type', methods=['GET'])
 def _type():
-	return 'worker'
+	return node_type
 
 # accepts two dicts, target and source
 # in any shared keys between the two will be overwritten to source's value, and any keys in source will be copied to target, with thei values
 def overwrite(target, source):
+	# to avoid aliasing
+	target = copy.copy(target)
 
 	for key in source:
 		target[key] = source[key]
@@ -72,11 +76,19 @@ def get_executor(configuration, fn):
 	else:
 		raise BaseException('unrecognized comms_pattern: '+str(comms_pattern))
 
-	executor = configuration['executor']
-	if (executor == 'Process'):
+	try:
+		executor = configuration['executor']
+	except(KeyError):
+		raise(KeyError('executor not specified in RPC configuration'))
+
+	if (executor == 'inline'):
+		executor = InlineExecutor
+	elif (executor == 'Process'):
 		executor = Process
 	elif((executor == 'Thread')):
 		executor = threading.Thread
+	else:
+		raise(BaseException('unrecognized executor configuration:', executor))
 
 	wrapped_fn = comms_wrapper(fn, executor)
 
@@ -122,4 +134,4 @@ def init(wrkr_name='worker'):
 
 	name = wrkr_name
 	# the web application that will serve the rpcs as routes
-	app.run(host='0.0.0.0', port=comms_config.worker_port)
\ No newline at end of file
+	app.run(host='0.0.0.0', port=comms_config.worker_port, threaded=False)
\ No newline at end of file
